@@ -1,5 +1,5 @@
 from firstimpression.api.request import request_json
-from firstimpression.time import parse_string_to_date, parse_string_time_to_minutes, parse_date_to_string
+from firstimpression.time import parse_string_to_date, parse_string_time_to_minutes, parse_date_to_string, parse_string_to_string
 
 
 def get_response(url, headers, params):
@@ -15,8 +15,8 @@ def get_departures(response_json):
     return response_json['payload']['departures']
 
 
-def get_departure_time(departure):
-    return departure['plannedDateTime'][:-5]
+def get_departure_time(departure, date_format):
+    return parse_string_to_string(departure['plannedDateTime'][:-5], date_format, '%H:%M')
 
 
 def get_actual_departure_time(departure):
@@ -93,7 +93,7 @@ def get_parsed_departures(response_json, date_format):
     for departure in departures:
         parsed_departure = dict()
         parsed_departure['departure_number'] = get_departure_number(departure)
-        parsed_departure['departure_time'] = get_departure_time(departure)
+        parsed_departure['departure_time'] = get_departure_time(departure, date_format)
         parsed_departure['destination'] = get_destination(departure)
         parsed_departure['train_category'] = get_train_category(departure)
         parsed_departure['route_text'] = get_route_text(departure)
